This class contains the list of repositories, respective links and categories at slot tables plus their relationships at slot keys (analogous to foreign keys).
tablesA list containing three data frames, namely data_sets (main table), links and keywords (categories).
keysA list containing two data frames relating these three tables, namely fk_links and fk_keywords.
Miguel Alvarez
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.